# -*- perl -*-

# t/03-methods.t - check that the methods work

use Test::Simple tests => 2;
use Music::Note::Frequency;

my $note = Music::Note::Frequency->new('C4','ISO');

print $note->frequency() . " should equal 261.625565300599 \n...only testing to 6 places...\n";
ok(sprintf("%.6f",$note->frequency()) == 261.625565);

$note->transpose(9);

print "A4 should be exactly 440 - and it equals " . $note->frequency() . "\n";

ok($note->frequency() == 440);

